==> nzbget-0.1.1.tar.gz: nzbget-0.1.1/MultiServerPool.cpp <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.1 $
 * $Date: 2004/02/24 11:05:48 $
 *
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "MultiServerPool.h"
#include "global.h"

MultiServerPool::MultiServerPool() 
{
  debug("MultiServerPool::MultiServerPool()\n");
  this->pools.clear();
}

void MultiServerPool::addServerPool(SingleServerPool* ssp)
{
  this->pools.push_back(ssp);
}


NNTPConnection* MultiServerPool::getConnection(unsigned int level)
{
  if (level >= this->pools.size())
    return NULL;
  SingleServerPool* ssp = this->pools[level];
  if (!ssp)
    return NULL;
  return ssp->getConnection();
}

void MultiServerPool::freeConnection(int level, NNTPConnection* conn)
{
  SingleServerPool* ssp = this->pools[level];
  if (!ssp)
    return;
  ssp->freeConnection(conn);
}

MultiServerPool* MultiServerPool::getInstance()
{
  static MultiServerPool singleton;
  return &singleton;
}

==> nzbget-0.2.0.tar.gz: nzbget-0.2.0/MultiServerPool.cpp <==
/*
 *  This file if part of nzbget
 *
 *  Copyright (C) 2004  Sven Henkel <sidddy@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Revision: 1.1 $
 * $Date: 2004/02/24 11:05:48 $
 *
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "MultiServerPool.h"
#include "global.h"

MultiServerPool::MultiServerPool() 
{
  debug("MultiServerPool::MultiServerPool()");
  this->pools.clear();
}

void MultiServerPool::addServerPool(SingleServerPool* ssp)
{
  this->pools.push_back(ssp);
}


NNTPConnection* MultiServerPool::getConnection(unsigned int level)
{
  if (level >= this->pools.size())
    return NULL;
  SingleServerPool* ssp = this->pools[level];
  if (!ssp)
    return NULL;
  return ssp->getConnection();
}

void MultiServerPool::freeConnection(int level, NNTPConnection* conn)
{
  SingleServerPool* ssp = this->pools[level];
  if (!ssp)
    return;
  ssp->freeConnection(conn);
}

MultiServerPool* MultiServerPool::getInstance()
{
  static MultiServerPool singleton;
  return &singleton;
}
